# coding: utf-8
# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220315


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AuthenticationMode(object):
    """
    These are the Authentication details of an OCI cache user.
    """

    #: A constant which can be used with the authentication_type property of a AuthenticationMode.
    #: This constant has a value of "IAM"
    AUTHENTICATION_TYPE_IAM = "IAM"

    #: A constant which can be used with the authentication_type property of a AuthenticationMode.
    #: This constant has a value of "PASSWORD"
    AUTHENTICATION_TYPE_PASSWORD = "PASSWORD"

    def __init__(self, **kwargs):
        """
        Initializes a new AuthenticationMode object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.redis.models.IamAuthenticationMode`
        * :class:`~oci.redis.models.PasswordAuthenticationMode`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param authentication_type:
            The value to assign to the authentication_type property of this AuthenticationMode.
            Allowed values for this property are: "IAM", "PASSWORD", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type authentication_type: str

        """
        self.swagger_types = {
            'authentication_type': 'str'
        }
        self.attribute_map = {
            'authentication_type': 'authenticationType'
        }
        self._authentication_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['authenticationType']

        if type == 'IAM':
            return 'IamAuthenticationMode'

        if type == 'PASSWORD':
            return 'PasswordAuthenticationMode'
        else:
            return 'AuthenticationMode'

    @property
    def authentication_type(self):
        """
        **[Required]** Gets the authentication_type of this AuthenticationMode.
        This is Authentication Type of OCI cache user

        Allowed values for this property are: "IAM", "PASSWORD", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The authentication_type of this AuthenticationMode.
        :rtype: str
        """
        return self._authentication_type

    @authentication_type.setter
    def authentication_type(self, authentication_type):
        """
        Sets the authentication_type of this AuthenticationMode.
        This is Authentication Type of OCI cache user


        :param authentication_type: The authentication_type of this AuthenticationMode.
        :type: str
        """
        allowed_values = ["IAM", "PASSWORD"]
        if not value_allowed_none_or_none_sentinel(authentication_type, allowed_values):
            authentication_type = 'UNKNOWN_ENUM_VALUE'
        self._authentication_type = authentication_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
